@@ -66,8 +66,8 @@ QByteArray NetworkManager::macAddressFromString(const QString &s)
         ba.resize(6);
         int i = 0;
 
-        foreach (const QString & macPart, macStringList) {
-            ba[i++] = macPart.toUInt(0, 16);
+        Q_FOREACH (const QString & macPart, macStringList) {
+            ba[i++] = macPart.toUInt(nullptr, 16);
         }
     }
     return ba;
@@ -351,7 +351,7 @@ NetworkManager::WirelessSecurityType NetworkManager::findBestWirelessSecurity(Ne
     // Static WEP users.
     types << NetworkManager::Wpa2Eap << NetworkManager::Wpa2Psk << NetworkManager::WpaEap << NetworkManager::WpaPsk << NetworkManager::StaticWep << NetworkManager::DynamicWep << NetworkManager::Leap << NetworkManager::NoneSecurity;
 
-    foreach (NetworkManager::WirelessSecurityType type, types) {
+    Q_FOREACH (NetworkManager::WirelessSecurityType type, types) {
         if (NetworkManager::securityIsValid(type, interfaceCaps, haveAp, adHoc, apCaps, apWpa, apRsn)) {
             return type;
         }
@@ -426,29 +426,27 @@ bool NetworkManager::wpaPskIsValid(const QString &psk)
 
 NetworkManager::WirelessSecurityType NetworkManager::securityTypeFromConnectionSetting(const NetworkManager::ConnectionSettings::Ptr &settings)
 {
-    NetworkManager::WirelessSetting::Ptr wifiSetting = settings->setting(Setting::Wireless).dynamicCast<WirelessSetting>();
-    if (!wifiSetting->security().isEmpty()) {
-        NetworkManager::WirelessSecuritySetting::Ptr wifiSecuritySetting = settings->setting(Setting::WirelessSecurity).dynamicCast<WirelessSecuritySetting>();
-        if (wifiSecuritySetting->keyMgmt() == WirelessSecuritySetting::Wep) {
-            return StaticWep;
-        } else if (wifiSecuritySetting->keyMgmt() == WirelessSecuritySetting::Ieee8021x) {
-            if (wifiSecuritySetting->authAlg() == WirelessSecuritySetting::Leap) {
-                return Leap;
-            } else {
-                return DynamicWep;
-            }
-        } else if (wifiSecuritySetting->keyMgmt() == WirelessSecuritySetting::WpaPsk) {
-            if (wifiSecuritySetting->proto().contains(WirelessSecuritySetting::Rsn) && !wifiSecuritySetting->proto().contains(WirelessSecuritySetting::Wpa)) {
-                return Wpa2Psk;
-            }
+    NetworkManager::WirelessSecuritySetting::Ptr wifiSecuritySetting = settings->setting(Setting::WirelessSecurity).dynamicCast<WirelessSecuritySetting>();
+    if (wifiSecuritySetting->keyMgmt() == WirelessSecuritySetting::Wep) {
+        return StaticWep;
+    } else if (wifiSecuritySetting->keyMgmt() == WirelessSecuritySetting::Ieee8021x) {
+        if (wifiSecuritySetting->authAlg() == WirelessSecuritySetting::Leap) {
+            return Leap;
+        } else {
+            return DynamicWep;
+        }
+    } else if (wifiSecuritySetting->keyMgmt() == WirelessSecuritySetting::WpaPsk) {
+        if (wifiSecuritySetting->proto().contains(WirelessSecuritySetting::Wpa) && !wifiSecuritySetting->proto().contains(WirelessSecuritySetting::Rsn)) {
             return WpaPsk;
-        } else if (wifiSecuritySetting->keyMgmt() == WirelessSecuritySetting::WpaEap) {
-            if (wifiSecuritySetting->proto().contains(WirelessSecuritySetting::Rsn) && !wifiSecuritySetting->proto().contains(WirelessSecuritySetting::Wpa)) {
-                return Wpa2Eap;
-            }
+        }
+        return Wpa2Psk;
+    } else if (wifiSecuritySetting->keyMgmt() == WirelessSecuritySetting::WpaEap) {
+        if (wifiSecuritySetting->proto().contains(WirelessSecuritySetting::Wpa) && !wifiSecuritySetting->proto().contains(WirelessSecuritySetting::Rsn)) {
             return WpaEap;
         }
+        return Wpa2Eap;
     }
+
     return NoneSecurity;
 }
 
